@@ -13,11 +13,10 @@
 #include "xvmodproc.h"
 
 void
-XvRegister()
+XvRegister(void)
 {
     XvScreenInitProc = XvScreenInit;
-    XvGetScreenIndexProc = XvGetScreenIndex;
+    XvGetScreenKeyProc = XvGetScreenKey;
     XvGetRTPortProc = XvGetRTPort;
     XvMCScreenInitProc = XvMCScreenInit;
 }
-
